# hpo-toolkit

A toolkit for working with Human Phenotype Ontology in Python

## Install

HPO toolkit is available from PyPi:

```shell
pip install hpo-toolkit
```

## Run tests

We use `tox` to run tests.
 
```shell
pip install tox
tox run
```

The `tox` runner generates an HTML coverage report file at `htmlcov/index.html`.

## Examples

Check out the [Jupyter 
notebooks](https://github.com/TheJacksonLaboratory/hpo-toolkit/tree/main/notebooks) for an example usage.

## Disclaimer

`hpo-toolkit` is still in *alpha* stage, the APIs may change.
